From 0f122cc50ca9304fe47fbff919b001bfdc6c933d Mon Sep 17 00:00:00 2001
From: Christophe Simonis <chs@odoo.com>
Date: Mon, 1 Sep 2014 15:49:26 +0200
Subject: [PATCH] [FIX] http.py: session id is `sid` attribute

---
 openerp/http.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/openerp/http.py b/openerp/http.py
index 9cd0bfa01978..281b239c265f 100644
--- a/openerp/http.py
+++ b/openerp/http.py
@@ -298,9 +298,9 @@ class WebRequest(object):
 
         .. deprecated:: 8.0
 
             Use the ``id`` attribute on :attr:`.session`
         """
-        return self.session.id
+        return self.session.sid
 
     @property
     def registry(self):
@@ -298,9 +298,9 @@ class WebRequest(object):
         .. deprecated:: 8.0
 
-            Use the ``id`` attribute on :attr:`.session`
+            Use the ``sid`` attribute on :attr:`.session`
         """
-- 
GitLab